@@ -1,6 +1,6 @@
 package Net::EC2::Tiny;
 {
-  $Net::EC2::Tiny::VERSION = '0.02';
+  $Net::EC2::Tiny::VERSION = '0.03';
 }
 
 use 5.014;
@@ -105,22 +105,37 @@ sub _sign {
         %args
     );
 
-    return $self->ua->post_form($self->base_url, \%params);
+    return \%params;
+}
 
+sub _request {
+    my $self   = shift;
+    my $params = shift;
+
+    return $self->ua->post_form( $self->base_url, $params );
+}
+
+sub _process {
+    my $self = shift;
+    my $data = shift;
+
+    my $xml = XMLin( $data,
+            ForceArray    => qr/(?:item|Errors)/i,
+            KeyAttr       => '',
+            SuppressEmpty => undef,
+    );
+
+    return $xml;
 }
 
 
 sub send {
-    my $self = shift;
-
-    my $response = $self->_sign(@_);
+    my $self     = shift;
+    my $request  = $self->_sign(@_);
+    my $response = $self->_request($request);
 
     if ( $response->{success} ) {
-        my $xml = XMLin($response->{content}, 
-                ForceArray    => qr/(?:item|Errors)/i,
-                KeyAttr       => '',
-                SuppressEmpty => undef,
-        );
+        my $xml = $self->_process( $response->{content} );
         if ( defined $xml->{Errors} ) {
             croak "Error: $response->{content}\n";
         }
@@ -143,7 +158,7 @@ Net::EC2::Tiny - Basic EC2 client
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
